summaryrefslogtreecommitdiff
path: root/src/testing/testing_api_cmd_patch_product.c
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2020-04-25 22:32:36 +0200
committerChristian Grothoff <christian@grothoff.org>2020-04-25 22:32:36 +0200
commit46aa711262566b7a8f358cbe684c64ed526a5edb (patch)
treef4defe802906f061e66ba1ce82247f3c4c8d1f1b /src/testing/testing_api_cmd_patch_product.c
parent23750b7d0622c7080ff8acde2b623568b98a88f4 (diff)
downloadmerchant-46aa711262566b7a8f358cbe684c64ed526a5edb.tar.gz
merchant-46aa711262566b7a8f358cbe684c64ed526a5edb.tar.bz2
merchant-46aa711262566b7a8f358cbe684c64ed526a5edb.zip
misc bugfixes
Diffstat (limited to 'src/testing/testing_api_cmd_patch_product.c')
-rw-r--r--src/testing/testing_api_cmd_patch_product.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/testing/testing_api_cmd_patch_product.c b/src/testing/testing_api_cmd_patch_product.c
index ec4bb4c4..9ddcdceb 100644
--- a/src/testing/testing_api_cmd_patch_product.c
+++ b/src/testing/testing_api_cmd_patch_product.c
@@ -87,7 +87,7 @@ struct PatchProductState
/**
* in @e units, -1 to indicate "infinite" (i.e. electronic books)
*/
- int64_t total_stocked;
+ int64_t total_stock;
/**
* in @e units.
@@ -172,7 +172,7 @@ patch_product_run (void *cls,
&pis->price,
pis->image,
pis->taxes,
- pis->total_stocked,
+ pis->total_stock,
pis->total_lost,
pis->address,
pis->next_restock,
@@ -225,9 +225,9 @@ patch_product_cleanup (void *cls,
* applicable taxes.
* @param image base64-encoded product image
* @param taxes list of taxes paid by the merchant
* @param total_stocked in @a units, -1 to indicate "infinite" (i.e. electronic books)
* @param total_lost in @a units, must be larger than previous values, and may
* not exceed total_stocked minus total_sold; if it does, the transaction
* will fail with a #MHD_HTTP_CONFLICT HTTP status code
* @param address where the product is in stock
* @param next_restock when the next restocking is expected to happen, 0 for unknown,
@@ -246,7 +246,7 @@ TALER_TESTING_cmd_merchant_patch_product (
const char *price,
json_t *image,
json_t *taxes,
- int64_t total_stocked,
+ int64_t total_stock,
uint64_t total_lost,
json_t *address,
struct GNUNET_TIME_Absolute next_restock,
@@ -266,7 +266,7 @@ TALER_TESTING_cmd_merchant_patch_product (
&pis->price));
pis->image = image; /* ownership taken */
pis->taxes = taxes; /* ownership taken */
- pis->total_stocked = total_stocked;
+ pis->total_stock = total_stock;
pis->total_lost = total_lost;
pis->address = address; /* ownership taken */
pis->next_restock = next_restock; {
@@ -225,9 +225,9 @@ patch_product_cleanup (void *cls,
* @param image base64-encoded product image
* @param taxes list of taxes paid by the merchant
- * @param total_stocked in @a units, -1 to indicate "infinite" (i.e. electronic books)
+ * @param total_stock in @a units, -1 to indicate "infinite" (i.e. electronic books)
* @param total_lost in @a units, must be larger than previous values, and may
@@ -225,9 +225,9 @@ patch_product_cleanup (void *cls,
* @param total_lost in @a units, must be larger than previous values, and may
- * not exceed total_stocked minus total_sold; if it does, the transaction
+ * not exceed total_stock minus total_sold; if it does, the transaction
* will fail with a #MHD_HTTP_CONFLICT HTTP status code
* @param address where the product is in stock